@@ -42,9 +42,9 @@
 // in the main development branch ("main") do not make any compatibility
 // guarantees at all.
 //
-#define OIIO_VERSION_MAJOR 2
-#define OIIO_VERSION_MINOR 5
-#define OIIO_VERSION_PATCH 18
+#define OIIO_VERSION_MAJOR 3
+#define OIIO_VERSION_MINOR 1
+#define OIIO_VERSION_PATCH 10
 #define OIIO_VERSION_TWEAK 0
 #define OIIO_VERSION_RELEASE_TYPE 
 
@@ -116,16 +116,37 @@
 #    define OIIO_DISABLE_DEPRECATED 0
 #endif
 
-// Establish the name spaces
-namespace OpenImageIO_v2_5 { }
-namespace OIIO = OpenImageIO_v2_5;
+// Establish the name spaces.
+//
+// The outer namespace defaults to OpenImageIO, but can be overriden at build
+// time. "OIIO" is always defined as an alias to this namespace, so client
+// software can always say `OIIO:Foo` without needing to know the custom outer
+// namespace.
+//
+// The primary inner namespace is vMAJ_MIN (or in main, vMAJ_MIN_PAT). The
+// outer namespace declares the inner namespace as "inline", so anything in it
+// is visible in OIIO by default.
 
-// Macros to use in each file to enter and exit the right name spaces.
-#define OIIO_NAMESPACE OpenImageIO_v2_5
-#define OIIO_NAMESPACE_STRING "OpenImageIO_v2_5"
-#define OIIO_NAMESPACE_BEGIN namespace OpenImageIO_v2_5 {
-#define OIIO_NAMESPACE_END }
+#define OIIO_OUTER_NAMESPACE OpenImageIO
+#define OIIO_CURRENT_INNER_NAMESPACE v3_1
+
+namespace OpenImageIO {
+    // Current version's new inner namespace is inline so it's used by default.
+    inline namespace v3_1 { }
+
+    // Legacy namespaces:
+    namespace v3_0 { }
+}
+namespace OIIO = OpenImageIO;
+
+
+// Macros to declare things in the current version's inline namespace.
+#define OIIO_NAMESPACE_BEGIN namespace OpenImageIO { inline namespace v3_1 {
+#define OIIO_NAMESPACE_END } }
 #define OIIO_NAMESPACE_USING using namespace OIIO;
+#define OIIO_CURRENT_NAMESPACE OpenImageIO::v3_1
+
+#include <OpenImageIO/nsversions.h>
 
 
 /// Each imageio DSO/DLL should include this statement:
@@ -167,8 +188,12 @@ namespace OIIO = OpenImageIO_v2_5;
 /// Version 24 Added a PIMPL pointers to ImageInput and ImageOutput and
 ///     removed some unnecessary fields that were exposed.
 /// Version 25 added the thumbnail retrieval and set. (OIIO 2.3)
+/// Version 26 deprecated the old stateful ImageInput::read_* methods.
+///     (OIIO 2.6.3/3.0)
+/// Version 27 added image_span-based versions of ImageInput::read_native_
+///     methods. (OIIO 3.1)
 
-#define OIIO_PLUGIN_VERSION 25
+#define OIIO_PLUGIN_VERSION 27
 
 #define OIIO_PLUGIN_NAMESPACE_BEGIN OIIO_NAMESPACE_BEGIN
 #define OIIO_PLUGIN_NAMESPACE_END OIIO_NAMESPACE_END
@@ -183,16 +208,16 @@ namespace OIIO = OpenImageIO_v2_5;
 
 // Which version of Imath is used in the OIIO API?
 #define OIIO_USING_IMATH_VERSION_MAJOR 3
-#define OIIO_USING_IMATH_VERSION_MINOR 1
+#define OIIO_USING_IMATH_VERSION_MINOR 2
 
-// Which CPP standard (11, 14, etc.) was this copy of OIIO *built* with?
-#define OIIO_BUILD_CPP 14
+// Which CPP standard (17, 20, etc.) was this copy of OIIO *built* with?
+#define OIIO_BUILD_CPP 17
 
 // DEPRECATED(2.1): old macros separately giving compatibility.
-#define OIIO_BUILD_CPP11 (14 >= 11)
-#define OIIO_BUILD_CPP14 (14 >= 14)
-#define OIIO_BUILD_CPP17 (14 >= 17)
-#define OIIO_BUILD_CPP20 (14 >= 20)
+#define OIIO_BUILD_CPP11 (17 >= 11)
+#define OIIO_BUILD_CPP14 (17 >= 14)
+#define OIIO_BUILD_CPP17 (17 >= 17)
+#define OIIO_BUILD_CPP20 (17 >= 20)
 
 
 // Was the project built with TBB support?
